[![pipeline status](https://gitlab.com/Tuuux/galaxie-docs/badges/master/pipeline.svg)](https://gitlab.com/Tuuux/galaxie-docs/-/commits/master) [![coverage report](https://gitlab.com/Tuuux/galaxie-docs/badges/master/coverage.svg)](https://gitlab.com/Tuuux/galaxie-docs/-/commits/master)

Galaxie Docs, The ToolKit
===========================
<div style="text-align:center"><img src ="https://gitlab.com/Tuuux/galaxie-curses/raw/master/docs/source/images/logo_galaxie.png" /></div>

The Project
-----------
**Galaxie Docs** is a free software Tool Kit for create MarkDown to HTML file.

Then the lib is write in **Python**

Installation
------------

**Pre Version**: ```pip install galaxie-docs```<BR>
**Dev Version**: ```pip install -i https://test.pypi.org/simple/ galaxie-docs```

Documentation:
-------------
* **Readthedocs link:** http://galaxie-docs.readthedocs.io


The Mission
-----------
Provide text based tool for create html file during survival period.

Contribute
----------
You welcome !!!

- Issue Tracker: https://gitlab.com/Tuuux/galaxie-docs/issues
- Source Code: https://gitlab.com/Tuuux/galaxie-docs


Screenshots
-----------
Coming soon

Example
-------
```bash
glxdoc-md2html ./tests/README.md ./tests/README.html
```

Features
--------
* CSS is includ inside html file
* Code coloration
* EveryMarkDown extension is enable
* Defensive code style

Roadmap
-------
Be the intenal Document wrapper for **Galaxie-Curses** lib .

* glxdoc-html2md

Thanks
------
To everyone i have interrest to it project, copy it, use it, diffuse it , and have fun ...

License
-------
GNU GENERAL PUBLIC LICENSE Version 3
https://gitlab.com/Tuuux/galaxie-docs/blob/master/LICENSE